@@ -2,7 +2,7 @@ use anyhow::Result;
 use structopt::StructOpt;
 use terra_rust_api::Terra;
 
-use bitcoin::secp256k1::Secp256k1;
+use secp256k1::Secp256k1;
 use terra_rust_wallet::Wallet;
 #[derive(StructOpt)]
 pub enum AuthCommand {
@@ -34,9 +34,9 @@ pub enum AuthCommand {
     },
 }
 
-pub async fn auth_cmd_parse<'a>(
-    terra: &Terra<'a>,
-    wallet: &Wallet<'a>,
+pub async fn auth_cmd_parse(
+    terra: &Terra,
+    wallet: &Wallet<'_>,
     seed: Option<&str>,
     auth_cmd: AuthCommand,
 ) -> Result<()> {
