@@ -12,6 +12,7 @@ mod bank;
 mod contract;
 
 mod auth;
+mod code;
 mod distribution;
 mod fcd;
 mod keys;
@@ -21,13 +22,16 @@ mod rpc;
 mod slashing;
 mod staking;
 mod tendermint;
+mod tx;
 mod validator;
 mod wallet;
+mod wasm;
 
 use anyhow::Result;
 
 use crate::auth::{auth_cmd_parse, AuthCommand};
 use crate::bank::{bank_cmd_parse, BankCommand};
+use crate::code::{code_cmd_parse, CodeCommand};
 use crate::contract::{contract_cmd_parse, ContractCommand};
 use crate::distribution::{distribution_cmd_parse, DistributionCommand};
 use crate::fcd::{fcd_cmd_parse, FCDCommand};
@@ -40,13 +44,16 @@ use crate::staking::{staking_cmd_parse, StakingCommand};
 use crate::tendermint::{
     block_cmd_parse, validator_sets_cmd_parse, BlockCommand, ValidatorSetsCommand,
 };
+use crate::tx::{tx_cmd_parse, TxCommand};
 use crate::validator::{validator_cmd_parse, ValidatorCommand};
 use crate::wallet::{wallet_cmd_parse, WalletCommand};
+use crate::wasm::{wasm_cmd_parse, WasmCommand};
 use terra_rust_api::core_types::Coin;
 use terra_rust_api::{GasOptions, Terra};
 use terra_rust_wallet::Wallet;
 
 /// VERSION number of package
+///
 pub const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
 /// NAME of package
 pub const NAME: Option<&'static str> = option_env!("CARGO_PKG_NAME");
@@ -221,14 +228,10 @@ enum Command {
     RPC(RPCCommand),
     /// FCD commands
     FCD(FCDCommand),
-}
-
-/// Input to the /txs/XXXX query
-#[derive(StructOpt)]
-pub struct TxCommand {
-    #[structopt(name = "hash", help = "hash to inquire about")]
-    /// The hash to inquire about
-    hash: String,
+    /// WASM commands
+    WASM(WasmCommand),
+    // set code
+    CODE(CodeCommand),
 }
 
 async fn run() -> anyhow::Result<()> {
@@ -240,8 +243,7 @@ async fn run() -> anyhow::Result<()> {
         &cli.chain_id,
         &gas_opts,
         Some(cli.debug.into_inner()),
-    )
-    .await?;
+    );
     let seed: Option<&str> = if cli.seed.is_empty() {
         None
     } else {
@@ -257,11 +259,7 @@ async fn run() -> anyhow::Result<()> {
         Command::Contract(cmd) => contract_cmd_parse(&t, &wallet, seed, cmd).await,
         Command::Market(cmd) => market_cmd_parse(&t, &wallet, seed, cmd).await,
 
-        Command::Tx(cmd) => {
-            let resp = t.tx().get(&cmd.hash).await?;
-            println!("{}", serde_json::to_string_pretty(&resp)?);
-            Ok(())
-        }
+        Command::Tx(cmd) => tx_cmd_parse(&t, cmd).await,
         Command::Auth(auth_cmd) => auth_cmd_parse(&t, &wallet, seed, auth_cmd).await,
         Command::Wallet(wallet_cmd) => wallet_cmd_parse(&t, &wallet, seed, wallet_cmd),
         Command::Slashing(cmd) => slashing_cmd_parse(&t, &wallet, seed, cmd).await,
@@ -270,6 +268,8 @@ async fn run() -> anyhow::Result<()> {
         Command::ValidatorSets(cmd) => validator_sets_cmd_parse(&t, cmd).await,
         Command::RPC(cmd) => rpc_cmd_parse(&t, cmd).await,
         Command::FCD(cmd) => fcd_cmd_parse(&t, &cli.fcd, cmd).await,
+        Command::WASM(cmd) => wasm_cmd_parse(&t, &wallet, seed, cmd).await,
+        Command::CODE(cmd) => code_cmd_parse(&t, &wallet, seed, cmd).await,
     }
 }
 #[tokio::main]
